@@ -1,7 +1,7 @@
 /* test-distrib.c --- testing distribution of nonprinting chars
 
 Copyright (C) 1987, 1993, 1994, 1995, 1999, 2001, 2002, 2003, 2004, 2005,
-              2006, 2007, 2008, 2009, 2010, 2011  Free Software Foundation, Inc.
+              2006, 2007, 2008, 2009, 2010, 2011, 2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
