@@ -1,5 +1,5 @@
 /* Copyright (C) 1993, 1995, 1997, 1999, 2001, 2002, 2003, 2004,
-      2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+      2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
