@@ -1,13 +1,13 @@
 /* Caching facts about regions of the buffer, for optimization.
-   Copyright (C) 1985, 1986, 1987, 1988, 1989, 1993, 1995
-	Free Software Foundation, Inc.
+   Copyright (C) 1985, 1986, 1987, 1988, 1989, 1993, 1995, 2001, 2002, 2003,
+                 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012  Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
 
-GNU Emacs is free software; you can redistribute it and/or modify
+GNU Emacs is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2, or (at your option)
-any later version.
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 GNU Emacs is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,18 +15,17 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with GNU Emacs; see the file COPYING.  If not, write to
-the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-Boston, MA 02111-1307, USA.  */
+along with GNU Emacs.  If not, see <http://www.gnu.org/licenses/>.  */
 
 
 #include <config.h>
+#include <stdio.h>
+#include <setjmp.h>
+
 #include "lisp.h"
 #include "buffer.h"
 #include "region-cache.h"
 
-#include <stdio.h>
-
 
 /* Data structures.  */
 
@@ -131,7 +130,7 @@ static void revalidate_region_cache ();
 struct region_cache *
 new_region_cache ()
 {
-  struct region_cache *c 
+  struct region_cache *c
     = (struct region_cache *) xmalloc (sizeof (struct region_cache));
 
   c->gap_start = 0;
@@ -143,8 +142,8 @@ new_region_cache ()
 
   c->beg_unchanged = 0;
   c->end_unchanged = 0;
-  c->buffer_beg = 1;
-  c->buffer_end = 1;
+  c->buffer_beg = BEG;
+  c->buffer_end = BEG;
 
   /* Insert the boundary for the buffer start.  */
   c->cache_len++;
@@ -385,7 +384,7 @@ delete_cache_boundaries (c, start, end)
 
   c->cache_len -= len;
 }
-     
+
 
 
 /* Set the value for a region.  */
@@ -407,12 +406,12 @@ set_cache_region (c, start, end, value)
      both the locations of real characters in the buffer.  */
   if (start == end)
     return;
-  
+
   {
     /* We need to make sure that there are no boundaries in the area
        between start to end; the whole area will have the same value,
        so those boundaries will not be necessary.
-       
+
        Let start_ix be the cache index of the boundary governing the
        first character of start..end, and let end_ix be the cache
        index of the earliest boundary after the last character in
@@ -456,7 +455,7 @@ set_cache_region (c, start, end, value)
             start_ix++;
           }
       }
-          
+
     /* This is equivalent to letting end_ix float (like a buffer
        marker does) with the insertions and deletions we may have
        done.  */
@@ -553,7 +552,7 @@ invalidate_region_cache (buf, c, head, tail)
 }
 
 
-/* Clean out any cache entries applying to the modified region, and 
+/* Clean out any cache entries applying to the modified region, and
    make the positions of the remaining entries accurate again.
 
    After calling this function, the mess described in the comment in
@@ -606,7 +605,7 @@ revalidate_region_cache (buf, c)
      (which will give the modified region the same size in the cache
      as it has in the buffer), and then invalidate the modified
      region. */
-  if (c->buffer_beg + c->beg_unchanged 
+  if (c->buffer_beg + c->beg_unchanged
       == c->buffer_end - c->end_unchanged)
     {
       /* Move the gap so that all the boundaries in the unchanged head
@@ -721,7 +720,7 @@ know_region_cache (buf, c, start, end)
 /* Interface: using the cache.  */
 
 /* Return true if the text immediately after POS in BUF is known, for
-   the purposes of CACHE.  If NEXT is non-zero, set *NEXT to the nearest 
+   the purposes of CACHE.  If NEXT is non-zero, set *NEXT to the nearest
    position after POS where the knownness changes.  */
 int
 region_cache_forward (buf, c, pos, next)
@@ -832,3 +831,6 @@ pp_cache (c)
       fprintf (stderr, "%d : %d\n", pos, BOUNDARY_VALUE (c, i));
     }
 }
+
+/* arch-tag: 98c29f3f-2ca2-4e3a-92f0-f2249200a17d
+   (do not change this comment) */
